package com.inspect.metadata.bdconfig.service;

import com.inspect.metadata.bdconfig.domain.BasedataBdConfigMainSystem;

import java.util.List;

public interface IBasedataBdConfigMainSystemService {
    BasedataBdConfigMainSystem selectBasedataBdConfigMainSystemByMainSystemId(Long mainSystemId);

    List<BasedataBdConfigMainSystem> selectBasedataBdConfigMainSystemList(BasedataBdConfigMainSystem mainSystem);

    int insertBasedataBdConfigMainSystem(BasedataBdConfigMainSystem mainSystem);

    int updateBasedataBdConfigMainSystem(BasedataBdConfigMainSystem mainSystem);

    int deleteBasedataBdConfigMainSystemByMainSystemIds(Long[] mainSystemIds);

    int deleteBasedataBdConfigMainSystemByMainSystemId(Long mainSystemId);
}
